@@ -5,32 +5,32 @@
 #'
 #' This function accepts the individual curve data in many different formats. If
 #' `data` is a `list`, each element of the list must contain a two
-#' column `data.frame` or `matrix` containing the XY data of the curves
+#' column `data.frame` or `matrix` containing the `XY` data of the curves
 #' (time and counts). Alternatively, the elements can be objects of class
 #' [RLum.Data.Curve-class].
-#' 
+#'
 #' Input values can also be provided as a `data.frame` or `matrix` where
 #' the first column contains the time values and each following column contains
 #' the counts of each curve.
 #'
-#' @param data [list], [data.frame], [matrix] or [RLum.Analysis-class] (**required**): 
+#' @param data [list], [data.frame], [matrix] or [RLum.Analysis-class] (**required**):
 #' X,Y data of measured values (time and counts). See details on individual data structure.
 #'
-#' @param log [character] (*optional*): 
+#' @param log [character] (*optional*):
 #' logarithmic axes (`c("x", "y", "xy")`).
 #'
-#' @param smooth [character] (*optional*): 
-#' apply data smoothing. Use `"rmean"` to calculate the rolling where `k` 
-#' determines the width of the rolling window (see [rollmean]). `"spline"` 
-#' applies a smoothing spline to each curve (see [smooth.spline])
+#' @param smooth [character] (*optional*):
+#' apply data smoothing. Use `"rmean"` to calculate the rolling where `k`
+#' determines the width of the rolling window (see [zoo::rollmean]). `"spline"`
+#' applies a smoothing spline to each curve (see [stats::smooth.spline])
 #'
-#' @param k [integer] (*with default*): 
+#' @param k [integer] (*with default*):
 #' integer width of the rolling window.
 #'
-#' @param legend [logical] (*with default*): 
+#' @param legend [logical] (*with default*):
 #' show or hide the plot legend.
 #'
-#' @param legend.pos [character] (*with default*): 
+#' @param legend.pos [character] (*with default*):
 #' keyword specifying the position of the legend (see [legend]).
 #'
 #' @param ... further parameters passed to [plot] (also see [par]).
@@ -123,17 +123,21 @@
 #' @export
 plot_NRt <- function(data, log = FALSE, smooth = c("none", "spline", "rmean"), k = 3,
                      legend = TRUE, legend.pos = "topright", ...) {
+  .set_function_name("plot_NRt")
+  on.exit(.unset_function_name(), add = TRUE)
 
   ## DATA INPUT EVALUATION -----
   if (inherits(data, "list")) {
     if (length(data) < 2)
-      stop(paste("The provided list only contains curve data of the natural signal"), call. = FALSE)
+      .throw_error("The provided list only contains curve data ",
+                   "of the natural signal")
     if (all(sapply(data, class) == "RLum.Data.Curve"))
       curves <- lapply(data, get_RLum)
   }
   else if (inherits(data, "data.frame") || inherits(data, "matrix")) {
     if (ncol(data) < 3)
-      stop(paste("The provided", class(data), "only contains curve data of the natural signal"), call. = FALSE)
+      .throw_error("The provided ", class(data)[1],
+                   " only contains curve data of the natural signal")
     if (is.matrix(data))
       data <- as.data.frame(data)
     curves <- apply(data[2:ncol(data)], MARGIN = 2, function(curve) {
@@ -142,11 +146,16 @@ plot_NRt <- function(data, log = FALSE, smooth = c("none", "spline", "rmean"), k
   }
   else if (inherits(data, "RLum.Analysis")) {
     RLum.objects <- get_RLum(data)
-    if (!any(sapply(RLum.objects, class) == "RLum.Data.Curve"))
-      stop(paste("The provided RLum.Analysis object must exclusively contain RLum.Data.Curve objects."), call. = FALSE)
+    if (any(sapply(RLum.objects, class) != "RLum.Data.Curve"))
+      .throw_error("The provided 'RLum.Analysis' object ",
+                   "must exclusively contain 'RLum.Data.Curve' objects")
     curves <- lapply(RLum.objects, get_RLum)
     if (length(curves) < 2)
-      stop(paste("The provided RLum.Analysis object only contains curve data of the natural signal"), call. = FALSE)
+      .throw_error("The provided 'RLum.Analysis' object ",
+                   "only contains curve data of the natural signal")
+  } else {
+    .throw_error("'data' is expected to be a list, matrix, data.frame or ",
+                 "'RLum.Analysis' object")
   }
 
   ## BASIC SETTINGS ------
@@ -154,6 +163,10 @@ plot_NRt <- function(data, log = FALSE, smooth = c("none", "spline", "rmean"), k
   regCurves <- curves[2:length(curves)]
   time <- curves[[1]][ ,1]
 
+  if (any(sapply(regCurves, nrow) != nrow(natural))) {
+    .throw_error("The time values for the natural signal don't match ",
+                 "those for the regenerated signal")
+  }
 
   ## DATA TRANSFORMATION -----
 
